settings
==================================================
**Module**: :mod:`espressodb.management.utilities.settings`


.. automodule:: espressodb.management.utilities.settings
    :members:
    :special-members:
    :exclude-members: ROOT_DIR, PROJECT_NAME

.. autodata:: ROOT_DIR
   :annotation: = 'path/to/current/project/root'

.. autodata:: PROJECT_NAME
   :annotation: = 'my_project'
